==> digikam_7.9.0.orig.tar.xz: digikam-7.9.0/core/dplugins/editor/enhance/lensautofix/lensautofixtoolplugin.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * https://www.digikam.org
 *
 * Date        : 2018-07-30
 * Description : image editor plugin to reduce lens artifacts
 *
 * Copyright (C) 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#ifndef DIGIKAM_LENSAUTOFIXTOOL_PLUGIN_H
#define DIGIKAM_LENSAUTOFIXTOOL_PLUGIN_H

// Local includes

#include "dplugineditor.h"

#define DPLUGIN_IID "org.kde.digikam.plugin.editor.LensAutoFixTool"

using namespace Digikam;

namespace DigikamEditorLensAutoFixToolPlugin
{

class LensAutoFixToolPlugin : public DPluginEditor
{
    Q_OBJECT
    Q_PLUGIN_METADATA(IID DPLUGIN_IID)
    Q_INTERFACES(Digikam::DPluginEditor)

public:

    explicit LensAutoFixToolPlugin(QObject* const parent = nullptr);
    ~LensAutoFixToolPlugin()             override;

    QString name()                 const override;
    QString iid()                  const override;
    QIcon   icon()                 const override;
    QString details()              const override;
    QString description()          const override;
    QList<DPluginAuthor> authors() const override;

    void setup(QObject* const)           override;

private Q_SLOTS:

    void slotLensAutoFix();
};

} // namespace DigikamEditorLensAutoFixToolPlugin

#endif // DIGIKAM_LENSAUTOFIXTOOL_PLUGIN_H

==> digikam_8.2.0.orig.tar.xz: digikam-8.2.0/core/dplugins/editor/enhance/lensautofix/lensautofixtoolplugin.h <==
/* ============================================================
 *
 * This file is a part of digiKam project
 * https://www.digikam.org
 *
 * Date        : 2018-07-30
 * Description : image editor plugin to reduce lens artifacts
 *
 * SPDX-FileCopyrightText: 2018-2022 by Gilles Caulier <caulier dot gilles at gmail dot com>
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 *
 * ============================================================ */

#ifndef DIGIKAM_LENSAUTOFIXTOOL_PLUGIN_H
#define DIGIKAM_LENSAUTOFIXTOOL_PLUGIN_H

// Local includes

#include "dplugineditor.h"

#define DPLUGIN_IID "org.kde.digikam.plugin.editor.LensAutoFixTool"

using namespace Digikam;

namespace DigikamEditorLensAutoFixToolPlugin
{

class LensAutoFixToolPlugin : public DPluginEditor
{
    Q_OBJECT
    Q_PLUGIN_METADATA(IID DPLUGIN_IID)
    Q_INTERFACES(Digikam::DPluginEditor)

public:

    explicit LensAutoFixToolPlugin(QObject* const parent = nullptr);
    ~LensAutoFixToolPlugin()             override;

    QString name()                 const override;
    QString iid()                  const override;
    QIcon   icon()                 const override;
    QString details()              const override;
    QString description()          const override;
    QList<DPluginAuthor> authors() const override;
    QString handbookSection()      const override;
    QString handbookChapter()      const override;
    QString handbookReference()    const override;

    void setup(QObject* const)           override;

private Q_SLOTS:

    void slotLensAutoFix();
};

} // namespace DigikamEditorLensAutoFixToolPlugin

#endif // DIGIKAM_LENSAUTOFIXTOOL_PLUGIN_H
